Welcome to remote_multicommand's documentation
==============================================

.. include:: ../../README.rst

remote_multicommand package contents:
=====================================

.. toctree::
   :maxdepth: 2

   remote_multicommand

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

